==> pytest_check_links-0.5.2.tar.gz: pytest_check_links-0.5.2/CHANGELOG.md <==
# Change Log

## 0.5.2

* Handle attachments in notebook cells [#36](https://github.com/jupyterlab/pytest-check-links/pull/36) ([@jtpio](https://github.com/jtpio))

## 0.5.1

* Fix handling of Nested RST links [#33](https://github.com/jupyterlab/pytest-check-links/pull/33) ([@jtpio](https://github.com/jtpio))
* Fix check-links-ignore example in Readme [#32](https://github.com/jupyterlab/pytest-check-links/pull/32) ([@blink1073](https://github.com/blink1073))

## 0.5.0

* Add Ability to Ignore Link Patterns [#30](https://github.com/jupyterlab/pytest-check-links/pull/30) ([@afshin](https://github.com/afshin))
* Test with python 3.9 in CI, deal with some windows issues [#27](https://github.com/jupyterlab/pytest-check-links/pull/27) ([@bollwyvl](https://github.com/bollwyvl))

## 0.4.4

* Remove defunct Travis CI [#24](https://github.com/jupyterlab/pytest-check-links/pull/24) ([@afshin](https://github.com/afshin))

## 0.4.3

* Update for recommended usage of CheckLinks [#22](https://github.com/jupyterlab/pytest-check-links/pull/22)

## 0.4.2

* Another improvement to retry logic [#20](https://github.com/jupyterlab/pytest-check-links/pull/20)

## 0.4.1

* Clean up metadata for dist generation [#19](https://github.com/jupyterlab/pytest-check-links/pull/19)
* Improve retry logic and add python 3 classifier [#18](https://github.com/jupyterlab/pytest-check-links/pull/18)

## 0.4.0

* Drop py27 support and add badges [#15](https://github.com/jupyterlab/pytest-check-links/pull/15)
* Use requests(-cache) [#12](https://github.com/jupyterlab/pytest-check-links/pull/12)
* Add checking of self- and local html anchors  [#10](https://github.com/jupyterlab/pytest-check-links/pull/10)

## 0.3.0

* Honor Retry-After Header [#9](https://github.com/jupyterlab/pytest-check-links/pull/9)
* Update metadata for JupyterLab Org [#7](https://github.com/jupyterlab/pytest-check-links/pull/7)

## 0.2.0

* Add rst handling [#4](https://github.com/jupyterlab/pytest-check-links/pull/4)

==> pytest_check_links-0.6.0.tar.gz: pytest_check_links-0.6.0/CHANGELOG.md <==
# Change Log

## 0.6.0

- Handle ignore links for `ipynb` files [#39](https://github.com/jupyterlab/pytest-check-links/pull/39) ([@pratyakshajha](https://github.com/pratyakshajha))
- Drop support for Python 3.6 and add support for Python 3.10 [#40](https://github.com/jupyterlab/pytest-check-links/pull/40) ([@blink1073](https://github.com/blink1073))

## 0.5.2

* Handle attachments in notebook cells [#36](https://github.com/jupyterlab/pytest-check-links/pull/36) ([@jtpio](https://github.com/jtpio))

## 0.5.1

* Fix handling of Nested RST links [#33](https://github.com/jupyterlab/pytest-check-links/pull/33) ([@jtpio](https://github.com/jtpio))
* Fix check-links-ignore example in Readme [#32](https://github.com/jupyterlab/pytest-check-links/pull/32) ([@blink1073](https://github.com/blink1073))

## 0.5.0

* Add Ability to Ignore Link Patterns [#30](https://github.com/jupyterlab/pytest-check-links/pull/30) ([@afshin](https://github.com/afshin))
* Test with python 3.9 in CI, deal with some windows issues [#27](https://github.com/jupyterlab/pytest-check-links/pull/27) ([@bollwyvl](https://github.com/bollwyvl))

## 0.4.4

* Remove defunct Travis CI [#24](https://github.com/jupyterlab/pytest-check-links/pull/24) ([@afshin](https://github.com/afshin))

## 0.4.3

* Update for recommended usage of CheckLinks [#22](https://github.com/jupyterlab/pytest-check-links/pull/22)

## 0.4.2

* Another improvement to retry logic [#20](https://github.com/jupyterlab/pytest-check-links/pull/20)

## 0.4.1

* Clean up metadata for dist generation [#19](https://github.com/jupyterlab/pytest-check-links/pull/19)
* Improve retry logic and add python 3 classifier [#18](https://github.com/jupyterlab/pytest-check-links/pull/18)

## 0.4.0

* Drop py27 support and add badges [#15](https://github.com/jupyterlab/pytest-check-links/pull/15)
* Use requests(-cache) [#12](https://github.com/jupyterlab/pytest-check-links/pull/12)
* Add checking of self- and local html anchors  [#10](https://github.com/jupyterlab/pytest-check-links/pull/10)

## 0.3.0

* Honor Retry-After Header [#9](https://github.com/jupyterlab/pytest-check-links/pull/9)
* Update metadata for JupyterLab Org [#7](https://github.com/jupyterlab/pytest-check-links/pull/7)

## 0.2.0

* Add rst handling [#4](https://github.com/jupyterlab/pytest-check-links/pull/4)
